==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/MaxAgePolicyFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MaxAgePolicyFluentImpl<A extends MaxAgePolicyFluent<A>> extends BaseFluent<A> implements MaxAgePolicyFluent<A>{
  public MaxAgePolicyFluentImpl() {
  }
  public MaxAgePolicyFluentImpl(MaxAgePolicy instance) {
    this.withLargestMaxAge(instance.getLargestMaxAge()); 
    this.withSmallestMaxAge(instance.getSmallestMaxAge()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Integer largestMaxAge;
  private Integer smallestMaxAge;
  private Map<String,Object> additionalProperties;
  public Integer getLargestMaxAge() {
    return this.largestMaxAge;
  }
  public A withLargestMaxAge(Integer largestMaxAge) {
    this.largestMaxAge=largestMaxAge; return (A) this;
  }
  public Boolean hasLargestMaxAge() {
    return this.largestMaxAge != null;
  }
  public Integer getSmallestMaxAge() {
    return this.smallestMaxAge;
  }
  public A withSmallestMaxAge(Integer smallestMaxAge) {
    this.smallestMaxAge=smallestMaxAge; return (A) this;
  }
  public Boolean hasSmallestMaxAge() {
    return this.smallestMaxAge != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MaxAgePolicyFluentImpl that = (MaxAgePolicyFluentImpl) o;
    if (largestMaxAge != null ? !largestMaxAge.equals(that.largestMaxAge) :that.largestMaxAge != null) return false;
    if (smallestMaxAge != null ? !smallestMaxAge.equals(that.smallestMaxAge) :that.smallestMaxAge != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(largestMaxAge,  smallestMaxAge,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (largestMaxAge != null) { sb.append("largestMaxAge:"); sb.append(largestMaxAge + ","); }
    if (smallestMaxAge != null) { sb.append("smallestMaxAge:"); sb.append(smallestMaxAge + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/MaxAgePolicyFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MaxAgePolicyFluentImpl<A extends MaxAgePolicyFluent<A>> extends BaseFluent<A> implements MaxAgePolicyFluent<A>{
  public MaxAgePolicyFluentImpl() {
  }
  public MaxAgePolicyFluentImpl(MaxAgePolicy instance) {
    if (instance != null) {
      this.withLargestMaxAge(instance.getLargestMaxAge());
      this.withSmallestMaxAge(instance.getSmallestMaxAge());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Integer largestMaxAge;
  private Integer smallestMaxAge;
  private Map<String,Object> additionalProperties;
  public Integer getLargestMaxAge() {
    return this.largestMaxAge;
  }
  public A withLargestMaxAge(Integer largestMaxAge) {
    this.largestMaxAge=largestMaxAge; return (A) this;
  }
  public Boolean hasLargestMaxAge() {
    return this.largestMaxAge != null;
  }
  public Integer getSmallestMaxAge() {
    return this.smallestMaxAge;
  }
  public A withSmallestMaxAge(Integer smallestMaxAge) {
    this.smallestMaxAge=smallestMaxAge; return (A) this;
  }
  public Boolean hasSmallestMaxAge() {
    return this.smallestMaxAge != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MaxAgePolicyFluentImpl that = (MaxAgePolicyFluentImpl) o;
    if (!java.util.Objects.equals(largestMaxAge, that.largestMaxAge)) return false;

    if (!java.util.Objects.equals(smallestMaxAge, that.smallestMaxAge)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(largestMaxAge,  smallestMaxAge,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (largestMaxAge != null) { sb.append("largestMaxAge:"); sb.append(largestMaxAge + ","); }
    if (smallestMaxAge != null) { sb.append("smallestMaxAge:"); sb.append(smallestMaxAge + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
